import { Injectable } from '@angular/core';
import { Observable, of } from 'rxjs';
import { HttpClient, HttpHeaders } from '@angular/common/http';

import { Wohnung } from './wohnung';
import { MessageService } from './message.service';
import { serviceBaseUrl } from './config';

@Injectable({
  providedIn: 'root'
})
export class WohnungService {
  constructor(private messageService: MessageService, private http: HttpClient) { }
  
  getWohnungen(): Promise<Wohnung[]> {
    this.messageService.add('WohnungService: fetched wohnungen');
    return this.http.get<Wohnung[]>(`${serviceBaseUrl}/hv/wohnungen`).toPromise()
  }

  getWohnungenByObjekt(objektId: number): Promise<Wohnung[]> {
    this.messageService.add(`WohnungService: fetched wohnungen by Objekt ${objektId}`);
    return this.http.get<Wohnung[]>(`${serviceBaseUrl}/hv/objekt/${objektId}/wohnungen`).toPromise()
  }

  getWohnung(id: number): Promise<Wohnung> {
    this.messageService.add(`WohnungService: fetch wohnung id=${id}`);
    return this.http.get<Wohnung>(`${serviceBaseUrl}/hv/wohnung/${id}`).toPromise()
  }
}
